@@ -423,7 +423,7 @@ class TrainingStep(ConfigurableRetryStep):
                 error_message="The step_args of TrainingStep must be obtained from estimator.fit().",
             )
 
-        self.step_args = step_args.args if step_args else None
+        self.step_args = step_args
         self.estimator = estimator
         self.inputs = inputs
 
@@ -431,7 +431,7 @@ class TrainingStep(ConfigurableRetryStep):
         self.cache_config = cache_config
 
         if self.cache_config:
-            if (self.step_args and "ProfilerConfig" in self.step_args) or (
+            if (self.step_args and "ProfilerConfig" in self.step_args.func_kwargs) or (
                 self.estimator is not None and not self.estimator.disable_profiler
             ):
                 msg = (
@@ -472,8 +472,16 @@ class TrainingStep(ConfigurableRetryStep):
         NOTE: The `CreateTrainingJob` request is not quite the args list that workflow needs.
         The `TrainingJobName` and `ExperimentConfig` attributes cannot be included.
         """
+        from sagemaker.workflow.utilities import execute_job_functions
+
         if self.step_args:
-            request_dict = self.step_args
+            # execute fit function with saved parameters,
+            # and store args in PipelineSession's _context
+            execute_job_functions(self.step_args)
+
+            # populate request dict with args
+            estimator = self.step_args.func_args[0]
+            request_dict = estimator.sagemaker_session.context.args
         else:
             self.estimator._prepare_for_training(self.job_name)
             train_args = _TrainingJob._get_train_args(
@@ -671,7 +679,7 @@ class TransformStep(ConfigurableRetryStep):
                 "from transformer.transform().",
             )
 
-        self.step_args = step_args.args if step_args else None
+        self.step_args = step_args
         self.transformer = transformer
         self.inputs = inputs
         self.cache_config = cache_config
@@ -695,8 +703,16 @@ class TransformStep(ConfigurableRetryStep):
         NOTE: The `CreateTransformJob` request is not quite the args list that workflow needs.
         `TransformJobName` and `ExperimentConfig` cannot be included in the arguments.
         """
+        from sagemaker.workflow.utilities import execute_job_functions
+
         if self.step_args:
-            request_dict = self.step_args
+            # execute transform function with saved parameters,
+            # and store args in PipelineSession's _context
+            execute_job_functions(self.step_args)
+
+            # populate request dict with args
+            transformer = self.step_args.func_args[0]
+            request_dict = transformer.sagemaker_session.context.args
         else:
             transform_args = _TransformJob._get_transform_args(
                 transformer=self.transformer,
@@ -800,7 +816,7 @@ class ProcessingStep(ConfigurableRetryStep):
                 error_message="The step_args of ProcessingStep must be obtained from processor.run().",
             )
 
-        self.step_args = step_args.args if step_args else None
+        self.step_args = step_args
         self.processor = processor
         self.inputs = inputs
         self.outputs = outputs
@@ -849,8 +865,16 @@ class ProcessingStep(ConfigurableRetryStep):
         NOTE: The `CreateProcessingJob` request is not quite the args list that workflow needs.
         `ProcessingJobName` and `ExperimentConfig` cannot be included in the arguments.
         """
+        from sagemaker.workflow.utilities import execute_job_functions
+
         if self.step_args:
-            request_dict = self.step_args
+            # execute run function with saved parameters,
+            # and store args in PipelineSession's _context
+            execute_job_functions(self.step_args)
+
+            # populate request dict with args
+            processor = self.step_args.func_args[0]
+            request_dict = processor.sagemaker_session.context.args
         else:
             normalized_inputs, normalized_outputs = self.processor._normalize_args(
                 job_name=self.job_name,
@@ -972,7 +996,7 @@ class TuningStep(ConfigurableRetryStep):
                 error_message="The step_args of TuningStep must be obtained from tuner.fit().",
             )
 
-        self.step_args = step_args.args if step_args else None
+        self.step_args = step_args
         self.tuner = tuner
         self.inputs = inputs
         self.job_arguments = job_arguments
@@ -1002,8 +1026,16 @@ class TuningStep(ConfigurableRetryStep):
             args list that workflow needs.
         The `HyperParameterTuningJobName` attribute cannot be included.
         """
+        from sagemaker.workflow.utilities import execute_job_functions
+
         if self.step_args:
-            request_dict = self.step_args
+            # execute fit function with saved parameters,
+            # and store args in PipelineSession's _context
+            execute_job_functions(self.step_args)
+
+            # populate request dict with args
+            tuner = self.step_args.func_args[0]
+            request_dict = tuner.sagemaker_session.context.args
         else:
             if self.tuner.estimator is not None:
                 self.tuner.estimator._prepare_for_training()
